Tempest scenarios
-----------------

*DO NOT RUN ON PRODUCTION*

* Tempest scenarios can purge whole cloud or left a lot of 
  undeleted resources

* Tempest scenrios are prof of concept. The main goal is 
  to answer on question why we need Rally and it's scenario
  and why we can't just use Tempest for benchmarking 

* Tempest scenarios have big overhead so you won't get
  any interesting performance data at all.


*DO NOT RUN ON PROUDCTION*
